// KreateCD - CD recording software for the K desktop environment
//
// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General      
// Public License.  See the file COPYING in the main directory of the       
// KreateCD distribution for more details.                                     

#ifndef TRACKDIALOG_INCLUDED
#define TRACKDIALOG_INCLUDED

#include <qwidget.h>
#include <qdialog.h>
#include <qlistview.h>

class TrackDialog : public QDialog {
  Q_OBJECT;
 public:
  TrackDialog( QWidget *parent=0, const char *name=0,class TOCReader *toc=0,
	       bool multisess=false);
 
  protected slots:
    void changeCurrent(QListViewItem *change);
  void cancelPressed(void);

 private:
  class QListView *tracklist;
  class QVBoxLayout *qvlayout;
  class QPushButton *qcancel;
};


#endif
